##############################################################################
#
# Copyright (c) 2009 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Test importability of BBB interfaces

$Id: test_interfaces.py 106799 2009-12-20 04:50:49Z fafhrd $
"""
import unittest
from zope.testing import doctest

def test_bbb_imports():
    """
    Let's check that permission vocabularies that were moved to
    zope.security are still importable from original place.

      >>> import zope.app.security.interfaces as old
      >>> import zope.authentication.interfaces as new

      >>> old.PrincipalLookupError is new.PrincipalLookupError
      True
      >>> old.IUnauthenticatedPrincipal is new.IUnauthenticatedPrincipal
      True
      >>> old.IFallbackUnauthenticatedPrincipal is new.IFallbackUnauthenticatedPrincipal
      True
      >>> old.IUnauthenticatedGroup is new.IUnauthenticatedGroup
      True
      >>> old.IAuthenticatedGroup is new.IAuthenticatedGroup
      True
      >>> old.IEveryoneGroup is new.IEveryoneGroup
      True
      >>> old.IAuthentication is new.IAuthentication
      True
      >>> old.ILoginPassword is new.ILoginPassword
      True
      >>> old.IPrincipalSource is new.IPrincipalSource
      True
      >>> old.ILogout is new.ILogout
      True
      >>> old.ILogoutSupported is new.ILogoutSupported
      True

      >>> import zope.security.interfaces as new

      >>> old.IPrincipal is new.IPrincipal
      True
      >>> old.IPermission is new.IPermission
      True
      >>> old.IGroup is new.IGroup
      True

    """

def test_suite():
    return unittest.TestSuite((
        doctest.DocTestSuite(),
        ))



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility import for security policy constants to allow
unpickling of old pickled security settings.

$Id: settings.py 97750 2009-03-10 00:47:21Z nadako $
"""
try:
    from zope.securitypolicy.settings import Allow, Deny, Unset
except ImportError:
    import logging
    logging.error('Allow, Unset and Deny constants are now '
                  'moved from zope.app.security.settings to '
                  'zope.securitypolicy.settings and you don\'t '
                  'seem to have it installed. This is very rare '
                  'case and you should manually install '
                  'the ``zope.securitypolicy`` package.')



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility imports for the global principal registry directives

$Id: metadirectives.py 106799 2009-12-20 04:50:49Z fafhrd $
"""

# BBB: these were moved to zope.principalregistry
from zope.principalregistry.metadirectives import (
        IBasePrincipalDirective,
        IDefinePrincipalDirective,
        IDefineUnauthenticatedPrincipalDirective,
        IDefineUnauthenticatedGroupDirective,
        IDefineAuthenticatedGroupDirective,
        IDefineEverybodyGroupDirective,
    )



##############################################################################
#
# Copyright (c) 2009 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility import for base ILoginPassword implementation.

$Id: loginpassword.py 97943 2009-03-12 00:38:29Z nadako $
"""

# BBB
from zope.authentication.loginpassword import LoginPassword



import os
import zope.app.testing.functional
import unittest

here = os.path.realpath(os.path.dirname(__file__))
PermissionsLayer = zope.app.testing.functional.ZCMLLayer(
    os.path.join(here, "ftesting.zcml"), __name__,
    "PermissionsLayer")

def test_suite():
    suite = zope.app.testing.functional.FunctionalDocFileSuite(
        'persistentlist.txt')
    suite.layer = PermissionsLayer
    return unittest.TestSuite([suite])



##############################################################################
#
# Copyright (c) 2004 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Doctests for 'permission' module.

$Id: test_permission.py 106799 2009-12-20 04:50:49Z fafhrd $
"""
import unittest
from zope.testing import doctest

def test_bbb_imports():
    """
    Let's test that backward-compatibility imports still work:

      >>> from zope.app.security import permission as old
      >>> from zope.app.localpermission import permission as new

      >>> old.NULL_ID is new.NULL_ID
      True
      >>> old.LocalPermission is new.LocalPermission
      True
      >>> old.setIdOnActivation is new.setIdOnActivation
      True
      >>> old.unsetIdOnDeactivation is new.unsetIdOnDeactivation
      True

    """

def test_suite():
    return unittest.TestSuite((
        doctest.DocTestSuite(),
        ))



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward compatibility: code was moved to zope.security.protectclass.

$Id: protectclass.py 95310 2009-01-28 13:16:45Z brandon_rhodes $
"""
from zope.security.checker import defineChecker, getCheckerForInstancesOf
from zope.security.checker import Checker, CheckerPublic

from zope.security.protectclass import (protectName,
                                        protectSetAttribute,
                                        protectLikeUnto)



##############################################################################
#
# Copyright (c) 2009 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward compatibility imports for zope.app.localpermission.

$Id: permission.py 98062 2009-03-13 23:49:38Z nadako $
"""
__docformat__ = 'restructuredtext'

# BBB: the functionality was moved to zope.app.localpermission
from zope.app.localpermission.permission import (
    NULL_ID,
    LocalPermission,
    setIdOnActivation,
    unsetIdOnDeactivation,
    )



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility imports for the global principal registry

$Id: principalregistry.py 97947 2009-03-12 02:31:26Z nadako $
"""

# BBB: these were moved to zope.principalregistry
from zope.principalregistry.principalregistry import (
    DuplicateLogin,
    DuplicateId,
    PrincipalRegistry,
    principalRegistry,
    PrincipalBase,
    Group,
    Principal,
    UnauthenticatedPrincipal,
    fallback_unauthenticated_principal,
    UnauthenticatedGroup,
    AuthenticatedGroup,
    EverybodyGroup,
    )



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility imports for the global principal registry directives

$Id: metaconfigure.py 97947 2009-03-12 02:31:26Z nadako $
"""
from zope.principalregistry.metaconfigure import (
    principal,
    unauthenticatedPrincipal,
    unauthenticatedGroup,
    authenticatedGroup,
    everybodyGroup,
    )



##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Global Authentication Serive or Principal Registry Tests

$Id: test_principalregistry.py 106799 2009-12-20 04:50:49Z fafhrd $
"""
import unittest
from zope.testing import doctest

def test_bbb_imports():
    """
    Let's check that principal registry that was moved to
    zope.principalregistry is still importable from original places.

      >>> import zope.app.security.principalregistry as old
      >>> import zope.principalregistry.principalregistry as new

      >>> old.DuplicateLogin is new.DuplicateLogin
      True
      >>> old.DuplicateId is new.DuplicateId
      True
      >>> old.PrincipalRegistry is new.PrincipalRegistry
      True
      >>> old.principalRegistry is new.principalRegistry
      True
      >>> old.PrincipalBase is new.PrincipalBase
      True
      >>> old.Group is new.Group
      True
      >>> old.Principal is new.Principal
      True
      >>> old.UnauthenticatedPrincipal is new.UnauthenticatedPrincipal
      True
      >>> old.fallback_unauthenticated_principal is new.fallback_unauthenticated_principal
      True
      >>> old.UnauthenticatedGroup is new.UnauthenticatedGroup
      True
      >>> old.AuthenticatedGroup is new.AuthenticatedGroup
      True
      >>> old.EverybodyGroup is new.EverybodyGroup
      True

      >>> import zope.app.security.metadirectives as old
      >>> import zope.principalregistry.metadirectives as new

      >>> old.IBasePrincipalDirective is new.IBasePrincipalDirective
      True
      >>> old.IDefinePrincipalDirective is new.IDefinePrincipalDirective
      True
      >>> old.IDefineUnauthenticatedPrincipalDirective is new.IDefineUnauthenticatedPrincipalDirective
      True
      >>> old.IDefineUnauthenticatedGroupDirective is new.IDefineUnauthenticatedGroupDirective
      True
      >>> old.IDefineAuthenticatedGroupDirective is new.IDefineAuthenticatedGroupDirective
      True
      >>> old.IDefineEverybodyGroupDirective is new.IDefineEverybodyGroupDirective
      True

      >>> import zope.app.security.metaconfigure as old
      >>> import zope.principalregistry.metaconfigure as new

      >>> old.principal is new.principal
      True
      >>> old.unauthenticatedPrincipal is new.unauthenticatedPrincipal
      True
      >>> old.unauthenticatedGroup is new.unauthenticatedGroup
      True
      >>> old.authenticatedGroup is new.authenticatedGroup
      True
      >>> old.everybodyGroup is new.everybodyGroup
      True

    """

def test_suite():
    return unittest.TestSuite((
        doctest.DocTestSuite(),
        ))
